@@ -4,7 +4,12 @@ import signal
 import sys
 from typing import Union
 from threading import Thread
-class load(object):
+
+
+def load(location, auto_dump):
+    return SynDB(location, auto_dump)
+
+class SynDB(object):
 
     key_error = TypeError('Key/name must be a string!')
 
@@ -95,4 +100,4 @@ class load(object):
             return False
         else:
             print(self.db)
-            return True
\ No newline at end of file
+            return True
